==> 13.10.x.tar.gz: fess/src/main/java/org/codelibs/fess/es/config/exentity/DuplicateHost.java <==
/*
 * Copyright 2012-2020 CodeLibs Project and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.codelibs.fess.es.config.exentity;

import org.codelibs.fess.es.config.bsentity.BsDuplicateHost;

/**
 * @author ESFlute (using FreeGen)
 */
public class DuplicateHost extends BsDuplicateHost {

    private static final long serialVersionUID = 1L;

    public String getId() {
        return asDocMeta().id();
    }

    public void setId(final String id) {
        asDocMeta().id(id);
    }

    public Long getVersionNo() {
        return asDocMeta().version();
    }

    public void setVersionNo(final Long version) {
        asDocMeta().version(version);
    }

    public String convert(final String url) {
        final String targetStr = getDuplicateHostName().replaceAll("\\.", "\\\\.");
        return url.replaceFirst("://" + targetStr + "$", "://" + getRegularName()).replaceFirst("://" + targetStr + "([:/])",
                "://" + getRegularName() + "$1");
    }

    @Override
    public String toString() {
        return "DuplicateHost [createdBy=" + createdBy + ", createdTime=" + createdTime + ", duplicateHostName=" + duplicateHostName
                + ", regularName=" + regularName + ", sortOrder=" + sortOrder + ", updatedBy=" + updatedBy + ", updatedTime=" + updatedTime
                + ", docMeta=" + docMeta + "]";
    }
}

==> 14.0.x.tar.gz: fess/src/main/java/org/codelibs/fess/es/config/exentity/DuplicateHost.java <==
/*
 * Copyright 2012-2022 CodeLibs Project and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.codelibs.fess.es.config.exentity;

import org.codelibs.fess.es.config.bsentity.BsDuplicateHost;

/**
 * @author ESFlute (using FreeGen)
 */
public class DuplicateHost extends BsDuplicateHost {

    private static final long serialVersionUID = 1L;

    public String getId() {
        return asDocMeta().id();
    }

    public void setId(final String id) {
        asDocMeta().id(id);
    }

    public Long getVersionNo() {
        return asDocMeta().version();
    }

    public void setVersionNo(final Long version) {
        asDocMeta().version(version);
    }

    public String convert(final String url) {
        final String targetStr = getDuplicateHostName().replace(".", "\\.");
        return url.replaceFirst("://" + targetStr + "$", "://" + getRegularName()).replaceFirst("://" + targetStr + "([:/])",
                "://" + getRegularName() + "$1");
    }

    @Override
    public String toString() {
        return "DuplicateHost [createdBy=" + createdBy + ", createdTime=" + createdTime + ", duplicateHostName=" + duplicateHostName
                + ", regularName=" + regularName + ", sortOrder=" + sortOrder + ", updatedBy=" + updatedBy + ", updatedTime=" + updatedTime
                + ", docMeta=" + docMeta + "]";
    }
}
